Welcome to sahara-tests's documentation!
========================================

Tests for the
`Sahara project <https://docs.openstack.org/sahara/latest/>`_.

It provides Sahara scenario tests framework and tempest tests.

User guide
----------

**Scenario Tests**

.. toctree::
   :maxdepth: 1

   scenario

**Tempest Plugin**

.. toctree::
   :maxdepth: 1

   tempest-plugin

Source
------

* License: Apache License, Version 2.0
* `PyPi`_ - package installation
* `Launchpad project`_ - release management
* `Blueprints`_ - feature specifications
* `Source`_
* `Specs`_
* :doc:`releasenotes`

.. _PyPi: https://pypi.python.org/pypi/sahara-tests
.. _Launchpad project: https://launchpad.net/sahara-tests
.. _Blueprints: https://blueprints.launchpad.net/sahara-tests
.. _Source: https://git.openstack.org/cgit/openstack/sahara-tests
.. _Specs: http://specs.openstack.org/openstack/sahara-specs/

Indices and tables
------------------

* :ref:`genindex`
* :ref:`search`

